package com.officetetsu.mymovieplayer;

import java.io.File;
import java.util.ArrayList;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.media.MediaPlayer;
import android.media.MediaPlayer.OnCompletionListener;
import android.media.MediaPlayer.OnErrorListener;
import android.media.MediaPlayer.OnPreparedListener;
import android.os.Bundle;
import android.os.Environment;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ArrayAdapter;
import android.widget.ImageButton;
import android.widget.MediaController;
import android.widget.Spinner;
import android.widget.Toast;
import android.widget.VideoView;

public class MyMoviePlayer extends Activity
	implements
	OnClickListener,
	OnPreparedListener,
	OnCompletionListener,
	OnErrorListener,
	DialogInterface.OnClickListener{
	
	private ImageButton imageButton;
	private Spinner spinner;
	private VideoView videoView;
	private String moviesroot;
	private String[] movies;
	private AlertDialog shutdownDialog;
	private ProgressDialog progressDialog;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		
		shutdownDialog = new AlertDialog.Builder(this)
		.setTitle(R.string.app_name)
		.setNeutralButton("OK", this)
		.setCancelable(false)
		.create();

		String state = Environment.getExternalStorageState();
		if(	!Environment.MEDIA_MOUNTED.equals(state) && 
			!Environment.MEDIA_MOUNTED_READ_ONLY.equals(state)
		){
			shutdownDialog.setMessage(getString(R.string.error_sd));
			shutdownDialog.show();
			return;
		}
		
		String sdroot = Environment.getExternalStorageDirectory().getPath();
		moviesroot = sdroot + "/Movies";
		File moviesrootdir = new File(moviesroot);
		if(! moviesrootdir.exists()){
			shutdownDialog.setMessage(getString(R.string.error_folder));
			shutdownDialog.show();
			return;
		}

		movies = moviesrootdir.list();
		ArrayList<String> tmp = new ArrayList<String>();
		for(String s: movies){
			if(s.endsWith("MP4") || s.endsWith("mp4"))
				tmp.add(s);
		}
		tmp.toArray(movies);

		if(movies.length == 0){
			shutdownDialog.setMessage(getString(R.string.error_file));
			shutdownDialog.show();
			return;
		}
		
		ArrayAdapter<CharSequence> arrayAdapter =
			new  ArrayAdapter<CharSequence>(
				this,
				android.R.layout.simple_spinner_item, 
				movies
			);

		spinner = (Spinner)findViewById(R.id.spinner1);
		spinner.setAdapter(arrayAdapter);

		imageButton = (ImageButton) findViewById(R.id.imageButton1);
		imageButton.setOnClickListener(this);
		
		videoView = (VideoView) findViewById(R.id.videoView1);
		videoView.setMediaController(new MediaController(this));
		videoView.requestFocus();
		videoView.setOnPreparedListener(this);
		videoView.setOnCompletionListener(this);
		videoView.setOnErrorListener(this);
	}

	@Override
	protected void onPause() {
		super.onPause();
		if(videoView != null)
			videoView.stopPlayback();
	}

	@Override
	public void onClick(DialogInterface arg0, int arg1) {
		// TODO Auto-generated method stub
		if(arg0 == shutdownDialog){
			finish();
		}
	}

	@Override
	public void onClick(View v) {
		// TODO Auto-generated method stub
		if(v == imageButton){
			int select = spinner.getSelectedItemPosition();

			try {
				videoView.setVideoPath(moviesroot + "/" + movies[select]);
			} catch (Exception e) {
				shutdownDialog.setMessage(getString(R.string.error_video));
				shutdownDialog.show();
				return;
			}

			progressDialog = new ProgressDialog(this);
			progressDialog.setTitle(R.string.app_name);
			progressDialog.setMessage(getString(R.string.prepared));
			progressDialog.show();
		}
	}

	@Override
	public void onPrepared(MediaPlayer arg0) {
		// TODO Auto-generated method stub
		progressDialog.dismiss();
		videoView.start();
		shutdownDialog.setMessage(getString(R.string.error_died));
		shutdownDialog.show();
	}

	@Override
	public void onCompletion(MediaPlayer mp) {
		// TODO Auto-generated method stub
		Toast.makeText(this, getString(R.string.completion), Toast.LENGTH_LONG).show();
	}

	@Override
	public boolean onError(MediaPlayer arg0, int arg1, int arg2) {
		// TODO Auto-generated method stub
		switch(arg1){
		case MediaPlayer.MEDIA_ERROR_SERVER_DIED:
			arg0.stop();
			arg0.release();
			arg0 = new MediaPlayer();
			Toast.makeText(this, getString(R.string.mpreflesh), Toast.LENGTH_LONG).show();
			return true;
		case MediaPlayer.MEDIA_ERROR_UNKNOWN:
			shutdownDialog.setMessage(getString(R.string.error_died));
			shutdownDialog.show();
			return true;
		}
		return false;
	}
}